#[non_exhaustive]pub struct ListNamespacesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
The request message for RegistrationService.ListNamespaces.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the project and location whose namespaces you’d like to list.
page_size: i32Optional. The maximum number of items to return.
page_token: StringOptional. The next_page_token value returned from a previous List request, if any.
filter: StringOptional. The filter to list results by.
General filter string syntax:
<field> <operator> <value> (<logical connector>)
<field>can benameorlabels.<key>for map field<operator>can be<,>,<=,>=,!=,=,:. Of which:meansHAS, and is roughly the same as=<value>must be the same data type as field<logical connector>can beAND,OR,NOT
Examples of valid filters:
labels.ownerreturns namespaces that have a label with the keyowner, this is the same aslabels:ownerlabels.owner=sdreturns namespaces that have key/valueowner=sdname>projects/my-project/locations/us-east1/namespaces/namespace-creturns namespaces that have name that is alphabetically later than the string, so “namespace-e” is returned but “namespace-a” is notlabels.owner!=sd AND labels.foo=barreturns namespaces that haveownerin label key but value is notsdAND have key/valuefoo=bardoesnotexist.foo=barreturns an empty list. Note that namespace doesn’t have a field called “doesnotexist”. Since the filter does not match any namespaces, it returns no results
For more information about filtering, see API Filtering.
order_by: StringOptional. The order to list results by.
General order_by string syntax: <field> (<asc|desc>) (,)
<field>allows value:name<asc|desc>ascending or descending order by<field>. If this is left blank,ascis used
Note that an empty order_by string results in default order, which is
order by name in ascending order.
Implementations
Sourceimpl ListNamespacesRequest
impl ListNamespacesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListNamespacesRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self