#[non_exhaustive]pub struct ListNamespacesResponse {
pub namespaces: Vec<Namespace>,
pub next_page_token: String,
/* private fields */
}Expand description
The response message for RegistrationService.ListNamespaces.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespaces: Vec<Namespace>The list of namespaces.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
Implementations
Sourceimpl ListNamespacesResponse
impl ListNamespacesResponse
Sourcepub fn set_namespaces<T, V>(self, v: T) -> Self
pub fn set_namespaces<T, V>(self, v: T) -> Self
Sets the value of namespaces.
Example
ⓘ
use google_cloud_servicedirectory_v1::model::Namespace;
let x = ListNamespacesResponse::new()
.set_namespaces([
Namespace::default()/* use setters */,
Namespace::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListNamespacesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListNamespacesResponse
impl Clone for ListNamespacesResponse
Sourcefn clone(&self) -> ListNamespacesResponse
fn clone(&self) -> ListNamespacesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListNamespacesResponse
impl Debug for ListNamespacesResponse
Sourceimpl Default for ListNamespacesResponse
impl Default for ListNamespacesResponse
Sourcefn default() -> ListNamespacesResponse
fn default() -> ListNamespacesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListNamespacesResponse
impl Message for ListNamespacesResponse
Sourceimpl PartialEq for ListNamespacesResponse
impl PartialEq for ListNamespacesResponse
impl StructuralPartialEq for ListNamespacesResponse