#[non_exhaustive]pub struct Namespace {
pub name: String,
pub labels: HashMap<String, String>,
pub uid: String,
/* private fields */
}Expand description
A container for services. Namespaces allow administrators to group services together and define permissions for a collection of services.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. The resource name for the namespace in the format
projects/*/locations/*/namespaces/*.
labels: HashMap<String, String>Optional. Resource labels associated with this namespace. No more than 64 user labels can be associated with a given resource. Label keys and values can be no longer than 63 characters.
uid: StringOutput only. The globally unique identifier of the namespace in the UUID4 format.
Implementations