ResolveServiceRequest

Struct ResolveServiceRequest 

#[non_exhaustive]
pub struct ResolveServiceRequest { pub name: String, pub max_endpoints: i32, pub endpoint_filter: String, /* private fields */ }
The request message for LookupService.ResolveService. Looks up a service by its name, returns the service and its endpoints.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The name of the service to resolve.

max_endpoints: i32

Optional. The maximum number of endpoints to return. Defaults to 25. Maximum is 100. If a value less than one is specified, the Default is used. If a value greater than the Maximum is specified, the Maximum is used.

endpoint_filter: String

Optional. The filter applied to the endpoints of the resolved service.

General filter string syntax: <field> <operator> <value> (<logical connector>)

  • <field> can be name, address, port, or annotations.<key> for map field
  • <operator> can be <, >, <=, >=, !=, =, :. Of which : means HAS, and is roughly the same as =
  • <value> must be the same data type as field
  • <logical connector> can be AND, OR, NOT

Examples of valid filters:

  • annotations.owner returns endpoints that have a annotation with the key owner, this is the same as annotations:owner
  • annotations.protocol=gRPC returns endpoints that have key/value protocol=gRPC
  • address=192.108.1.105 returns endpoints that have this address
  • port>8080 returns endpoints that have port number larger than 8080

name>projects/my-project/locations/us-east1/namespaces/my-namespace/services/my-service/endpoints/endpoint-c returns endpoints that have name that is alphabetically later than the string, so “endpoint-e” is returned but “endpoint-a” is not * name=projects/my-project/locations/us-central1/namespaces/my-namespace/services/my-service/endpoints/ep-1 returns the endpoint that has an endpoint_id equal to ep-1

  • annotations.owner!=sd AND annotations.foo=bar returns endpoints that have owner in annotation key but value is not sd AND have key/value foo=bar
  • doesnotexist.foo=bar returns an empty list. Note that endpoint doesn’t have a field called “doesnotexist”. Since the filter does not match any endpoint, it returns no results

For more information about filtering, see API Filtering.

Implementations

Source

impl ResolveServiceRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = ResolveServiceRequest::new().set_name(format!("projects/{project_id}/locations/{location_id}/namespaces/{namespace_id}/services/{service_id}"));
pub fn set_max_endpoints<T: Into<i32>>(self, v: T) -> Self

Sets the value of max_endpoints.

Example
let x = ResolveServiceRequest::new().set_max_endpoints(42);
pub fn set_endpoint_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of endpoint_filter.

Example
let x = ResolveServiceRequest::new().set_endpoint_filter("example");